from pathlib import Path
from loguru import logger as log

MODULE_BASE_DIRECTORY = Path("/tmp")

__all__ = ["log", MODULE_BASE_DIRECTORY]
